@@ -1,4 +1,7 @@
+import inspect
 import re
+import textwrap
+import traceback
 from typing import Optional
 
 import pytest
@@ -32,6 +35,7 @@ def parse_markdown(text: str) -> list[CodeSnippet]:
     lines = text.splitlines()
     pending_name: Optional[str] = None
     pending_marks: list[str] = [CODEBLOCK_MARK]
+    pending_fixtures: list[str] = []
     in_block = False
     fence = ""
     block_indent = 0
@@ -50,6 +54,13 @@ def parse_markdown(text: str) -> list[CodeSnippet]:
                     pending_marks.append(m.group(1))
                 continue
 
+            # Check for pytest fixture comment
+            if stripped.startswith("<!--") and "pytestfixture:" in stripped:
+                m = re.match(r"<!--\s*pytestfixture:\s*(\w+)\s*-->", stripped)
+                if m:
+                    pending_fixtures.append(m.group(1))
+                continue
+
             # Check for name comment
             if stripped.startswith("<!--") and "codeblock-name:" in stripped:
                 m = re.match(
@@ -105,6 +116,7 @@ def parse_markdown(text: str) -> list[CodeSnippet]:
                     code=code_text,
                     line=start_line,
                     marks=pending_marks.copy(),
+                    fixtures=pending_fixtures.copy(),
                 ))
                 # reset pending marks after collecting
                 pending_marks.clear()
@@ -138,17 +150,56 @@ class MarkdownFile(pytest.File):
         combined = group_snippets(tests)
 
         for sn in combined:
-            # generate a real pytest Function so fixtures work
-            if DJANGO_DB_MARKS.intersection(sn.marks):
-                def make_func(code):
-                    def test_block(db):
-                        exec(code, {})
-                    return test_block
-            else:
-                def make_func(code):
-                    def test_block():
-                        exec(code, {})
-                    return test_block
+            # Bind the values we need so we don't close over `sn` itself
+            _sn_name = sn.name
+            _fpath = str(self.path)
+
+            # Build list of fixture names requested by this snippet
+            _fixture_names: list[str] = list(sn.fixtures)
+
+            # If snippet is marked as needing DB, also request the `db`
+            # fixture, unless user already added it explicitly.
+            if (
+                DJANGO_DB_MARKS.intersection(sn.marks)
+                and "db" not in _fixture_names
+            ):
+                _fixture_names.append("db")
+
+            # Generate a real pytest Function so fixtures work
+            def make_func(
+                code,
+                sn_name=_sn_name,
+                fpath=_fpath,
+                fixture_names=_fixture_names,
+            ):
+                # This inner function *actually* has a **fixtures signature,
+                # but we override __signature__ so pytest passes the right
+                # fixtures and names.
+                def test_block(**fixtures):
+                    compiled = compile(code, fpath, "exec")
+                    try:
+                        # Make fixtures available as top-level names
+                        # inside the executed snippet.
+                        exec(compiled, dict(fixtures))
+                    except Exception as err:
+                        raise Exception(
+                            f"Error in "
+                            f"codeblock `{sn_name}` in {fpath}:\n"
+                            f"\n{textwrap.indent(code, prefix='    ')}\n\n"
+                            f"{traceback.format_exc()}"
+                        ) from err
+
+                # Tell pytest which fixture arguments this test has:
+                test_block.__signature__ = inspect.Signature(
+                    [
+                        inspect.Parameter(
+                            name,
+                            inspect.Parameter.POSITIONAL_OR_KEYWORD,
+                        )
+                        for name in fixture_names
+                    ]
+                )
+                return test_block
 
             callobj = make_func(sn.code)
             fn = pytest.Function.from_parent(
